//Source file: Call.java
//Date: February 2004
//Generic Call Control Interfaces for 3GPP TS 29.198-04-2 V6.0.0, Release 6

package org.csapi.jr.se.cc.gccs;

/**
 * This interface represents a Call.<BR>
 *
 */
public interface Call extends org.csapi.jr.se.Service {

    /**
     * Adds a CallListener which is interested in events generated by the Call.
     *
     * @param  callListener  A reference to the CallListener which is to be added as
     *         a listener.
     */
    void addCallListener(org.csapi.jr.se.cc.gccs.CallListener callListener);

    /**
     * Removes a CallListener which is no longer interested in events generated by the Call.
     *
     * @param  callListener  A reference to the CallListener which is to be removed as
     *         a listener.
     */
    void removeCallListener(org.csapi.jr.se.cc.gccs.CallListener callListener);

    /**
     * Returns a reference to the CallControlManager responsible for creation of the Call.
     *
     * @return  A reference to the CallControlManager responsible for creation of the Call.
     */
    org.csapi.jr.se.cc.gccs.CallControlManager getCallControlManager();

    /**
     * Invokes the release() method on the Parlay Gateway.
     */
    void release(
           org.csapi.jr.se.cc.gccs.CallReleaseCause cause)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.InvalidNetworkStateException;

    /**
     * Invokes the deassignCall() method on the Parlay Gateway.
     */
    void deassignCall()
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the getCallInfoReq() method on the Parlay Gateway.
     */
    void getCallInfoReq(
           int                             callInfoRequested)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the setCallChargePlan() method on the Parlay Gateway.
     */
    void setCallChargePlan(
           org.csapi.jr.se.cc.CallChargePlan callChargePlan)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the setAdviceOfCharge() method on the Parlay Gateway.
     */
    void setAdviceOfCharge(
           org.csapi.jr.se.AoCInfo aOCInfo,
           int                             tariffSwitch)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the getMoreDialledDigitsReq() method on the Parlay Gateway.
     */
    void getMoreDialledDigitsReq(
           int                             length)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the superviseCallReq() method on the Parlay Gateway.
     */
    void superviseCallReq(
           int                             time,
           int                             treatment)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Creates a Route object and returns a reference to the interface used to gain access
     * to it's methods.
     *
     * @return  A reference to the Route interface.
     */
    org.csapi.jr.se.cc.gccs.Route createRoute();

}
